#!/usr/bin/env python

""" This program controls the NXT to wander around, and if bumps something, to turn a bit and go on."""

import nxt.locator
from nxt.motor import *
from nxt.sensor import *

class MotorW(Motor):
	def __init__(self, brick, port):
		Motor.__init__(self, brick, port)

	def set_speed(self, power, cutoff=30):
		self.power = power
		
		if (self.power > 0 and self.power < cutoff) or (self.power<0 and self.power > - cutoff):
			self.mode = MODE_IDLE
			self.run_state = RUN_STATE_IDLE
		else:
			self.mode = MODE_MOTOR_ON
			self.run_state = RUN_STATE_RUNNING
		self.set_output_state()

	def turn(self, deg):
		self.mode = MODE_MOTOR_ON
		self.run_state = RUN_STATE_RUNNING
		self.reset_position(0)
		if deg < 0:
			self.power = -80
			deg = - deg
		else:
			self.power = 80
			
		self.tacho_limit = deg
		self.set_output_state()

sock = nxt.locator.find_one_brick()
if sock:
	brick = sock.connect()
	name, host, signal_strength, user_flash = brick.get_device_info()
	print 'NXT brick name: %s' % name
	print 'Host address: %s' % host
	print 'Bluetooth signal strength: %s' % signal_strength
	print 'Free user flash: %s' % user_flash
	
	
	import time
	
	m_b = MotorW(brick, PORT_B)
	m_c = MotorW(brick, PORT_C)
	
	

	
	
	while 1:
		time.sleep(0.02)
		m_b.set_speed(100)
		m_c.set_speed(100)
		
		if TouchSensor(brick, PORT_2).get_sample():
			m_b.set_speed(-20)
			m_c.set_speed(-100)
			time.sleep(1)
		elif TouchSensor(brick, PORT_3).get_sample():
			m_b.set_speed(-100)
			m_c.set_speed(-20)
			time.sleep(1)
	
	
	sock.close()