#!/usr/bin/env python

""" Controls the NXT with the Wiimote.

- Arrow Keys: Move
- Minus/Plus: Increases/Decreases velocity (useful for turning)
- If it bumps something, the wiimote rumbles and lights the LEDs for each sensor.

"""


import nxt.locator
from nxt.motor import *
from nxt.sensor import *

class MotorW(Motor):
	def __init__(self, brick, port):
		Motor.__init__(self, brick, port)

	def set_speed(self, power, cutoff=30):
		self.power = power
		
		if (self.power > 0 and self.power < cutoff) or (self.power<0 and self.power > - cutoff):
			self.mode = MODE_IDLE
			self.run_state = RUN_STATE_IDLE
		else:
			self.mode = MODE_MOTOR_ON
			self.run_state = RUN_STATE_RUNNING
		self.set_output_state()

	def turn(self, deg):
		self.mode = MODE_MOTOR_ON
		self.run_state = RUN_STATE_RUNNING
		self.reset_position(0)
		if deg < 0:
			self.power = -80
			deg = - deg
		else:
			self.power = 80
			
		self.tacho_limit = deg
		self.set_output_state()
		

import sys, os, time
from wiimote import *
import lightblue

MAC = None
for device in lightblue.finddevices():
	print device
	if device[1] == u"Nintendo RVL-CNT-01":
		MAC = device[0]
if not MAC:
	print "No Wiimote found!"
	sys.exit()
		
wii = wiimoteLibClass( MAC )
wii.activate_accel()
#wii.activate_IR()
wii.setContinuous( True )




sock = nxt.locator.find_one_brick()
if sock:
	brick = sock.connect()
	name, host, signal_strength, user_flash = brick.get_device_info()
	print 'NXT brick name: %s' % name
	print 'Host address: %s' % host
	print 'Bluetooth signal strength: %s' % signal_strength
	print 'Free user flash: %s' % user_flash


	m_b = MotorW(brick, PORT_B)
	m_c = MotorW(brick, PORT_C)

	r_s = TouchSensor(brick, PORT_2)
	l_s = TouchSensor(brick, PORT_3)

	v = 100

	while True:
		time.sleep(0.001)
		wii.step()
		
		right_sensor = r_s.get_sample()
		left_sensor = l_s.get_sample()
			
		if wii.wiiMoteState.ButtonMinus:
			if v > 10:
				v -= 10
		if wii.wiiMoteState.ButtonPlus:
			if v < 120:
				v += 10

		if right_sensor or left_sensor:
			wii.SetRumble(True)
			wii.SetLEDs(left_sensor,0,0,right_sensor)
		else:
			wii.SetRumble(False)
			wii.SetLEDs(0,0,0,0)
		
		
		if wii.wiiMoteState.ButtonUp:
			m_b.set_speed(v)
			m_c.set_speed(v)
		elif wii.wiiMoteState.ButtonDown:
			m_b.set_speed(-v)
			m_c.set_speed(-v)
		elif wii.wiiMoteState.ButtonRight:
			m_b.set_speed(-v)
			m_c.set_speed(v)
		elif wii.wiiMoteState.ButtonLeft:
			m_b.set_speed(v)
			m_c.set_speed(-v)
		else:
			m_b.set_speed(0)
			m_c.set_speed(0)
		
		# trying to control through the accelarometer
		#m_b.set_speed(100*(wii.wiiMoteState.AccelY * 128)/2.7)
		#m_c.set_speed(100*(wii.wiiMoteState.AccelY * 128)/2.7)

	sock.close()

